summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/oscar/aim/aimcontact.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/protocols/oscar/aim/aimcontact.h')
-rw-r--r--kopete/protocols/oscar/aim/aimcontact.h36
1 files changed, 18 insertions, 18 deletions
diff --git a/kopete/protocols/oscar/aim/aimcontact.h b/kopete/protocols/oscar/aim/aimcontact.h
index 458db2f5..a246c029 100644
--- a/kopete/protocols/oscar/aim/aimcontact.h
+++ b/kopete/protocols/oscar/aim/aimcontact.h
@@ -18,7 +18,7 @@
#ifndef AIMCONTACT_H
#define AIMCONTACT_H
-#include <qdatetime.h>
+#include <tqdatetime.h>
#include "oscarcontact.h"
@@ -37,25 +37,25 @@ class AIMContact : public OscarContact
Q_OBJECT
public:
- AIMContact( Kopete::Account*, const QString&, Kopete::MetaContact*,
- const QString& icon = QString::null, const Oscar::SSI& ssiItem = Oscar::SSI() );
+ AIMContact( Kopete::Account*, const TQString&, Kopete::MetaContact*,
+ const TQString& icon = TQString::null, const Oscar::SSI& ssiItem = Oscar::SSI() );
virtual ~AIMContact();
bool isReachable();
- QPtrList<KAction> *customContextMenuActions();
+ TQPtrList<KAction> *customContextMenuActions();
- const QString &userProfile() { return mUserProfile; }
+ const TQString &userProfile() { return mUserProfile; }
- virtual const QString awayMessage();
- virtual void setAwayMessage( const QString &message );
+ virtual const TQString awayMessage();
+ virtual void setAwayMessage( const TQString &message );
int warningLevel() const;
/**
* Gets the last time an autoresponse was sent to this contact
* @returns QDateTime Object that represents the date/time
*/
- QDateTime lastAutoResponseTime() {return m_lastAutoresponseTime;}
+ TQDateTime lastAutoResponseTime() {return m_lastAutoresponseTime;}
/** Sends an auto response to this contact */
virtual void sendAutoResponse(Kopete::Message& msg);
@@ -63,12 +63,12 @@ public:
public slots:
void updateSSIItem();
void slotUserInfo();
- void userInfoUpdated( const QString& contact, const UserDetails& details );
- void userOnline( const QString& userId );
- void userOffline( const QString& userId );
- void updateAwayMessage( const QString& userId, const QString& message );
- void updateProfile( const QString& contact, const QString& profile );
- void gotWarning( const QString& contact, Q_UINT16, Q_UINT16 );
+ void userInfoUpdated( const TQString& contact, const UserDetails& details );
+ void userOnline( const TQString& userId );
+ void userOffline( const TQString& userId );
+ void updateAwayMessage( const TQString& userId, const TQString& message );
+ void updateProfile( const TQString& contact, const TQString& profile );
+ void gotWarning( const TQString& contact, Q_UINT16, Q_UINT16 );
signals:
void updatedProfile();
@@ -79,7 +79,7 @@ protected slots:
private slots:
void requestBuddyIcon();
- void haveIcon( const QString&, QByteArray );
+ void haveIcon( const TQString&, TQByteArray );
void closeUserInfoDialog();
void warnUser();
@@ -89,10 +89,10 @@ private slots:
private:
AIMProtocol* mProtocol;
AIMUserInfoDialog* m_infoDialog;
- QString mUserProfile;
+ TQString mUserProfile;
bool m_haveAwayMessage;
bool m_mobile; // Is this user mobile (i.e. do they have message forwarding on, or mobile AIM)
- QDateTime m_lastAutoresponseTime;
+ TQDateTime m_lastAutoresponseTime;
KAction* m_warnUserAction;
KToggleAction *m_actionVisibleTo;
@@ -37,25 +37,25 @@ class AIMContact : public OscarContact
/**
* Gets the last time an autoresponse was sent to this contact
- * @returns QDateTime Object that represents the date/time
+ * @returns TQDateTime Object that represents the date/time
*/